# coding: utf-8

"""
Trading API

API for automated trading and exchange interface

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from crypticorn.trade.client.models.strategy_exchange_info import StrategyExchangeInfo
from typing import Optional, Set
from typing_extensions import Self


class StrategyModelOutput(BaseModel):
    """
    StrategyModelOutput
    """  # noqa: E501

    created_at: Optional[StrictInt] = None
    updated_at: Optional[StrictInt] = None
    id: Optional[StrictStr] = None
    identifier: StrictStr = Field(
        description="Unique human readable identifier for the strategy e.g. 'daily_trend_momentum'"
    )
    name: StrictStr = Field(description="Name of the strategy")
    description: StrictStr = Field(description="Description of the strategy")
    exchanges: List[StrategyExchangeInfo] = Field(
        description="Exchanges supported by the strategy."
    )
    enabled: StrictBool = Field(
        description="Whether the strategy is enabled. If false, no bots will be created or updated for this strategy, open trades will be rejected. Existing bots will be marked as stopping."
    )
    leverage: StrictInt = Field(description="Leverage for the strategy")
    performance_fee: Union[
        Annotated[float, Field(le=1.0, strict=True)],
        Annotated[int, Field(le=1, strict=True)],
    ] = Field(description="Performance fee for the strategy")
    market_type: StrictStr = Field(description="Market types")
    __properties: ClassVar[List[str]] = [
        "created_at",
        "updated_at",
        "id",
        "identifier",
        "name",
        "description",
        "exchanges",
        "enabled",
        "leverage",
        "performance_fee",
        "market_type",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of StrategyModelOutput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in exchanges (list)
        _items = []
        if self.exchanges:
            for _item_exchanges in self.exchanges:
                if _item_exchanges:
                    _items.append(_item_exchanges.to_dict())
            _dict["exchanges"] = _items
        # set to None if created_at (nullable) is None
        # and model_fields_set contains the field
        if self.created_at is None and "created_at" in self.model_fields_set:
            _dict["created_at"] = None

        # set to None if updated_at (nullable) is None
        # and model_fields_set contains the field
        if self.updated_at is None and "updated_at" in self.model_fields_set:
            _dict["updated_at"] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict["id"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of StrategyModelOutput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "created_at": obj.get("created_at"),
                "updated_at": obj.get("updated_at"),
                "id": obj.get("id"),
                "identifier": obj.get("identifier"),
                "name": obj.get("name"),
                "description": obj.get("description"),
                "exchanges": (
                    [
                        StrategyExchangeInfo.from_dict(_item)
                        for _item in obj["exchanges"]
                    ]
                    if obj.get("exchanges") is not None
                    else None
                ),
                "enabled": obj.get("enabled"),
                "leverage": obj.get("leverage"),
                "performance_fee": obj.get("performance_fee"),
                "market_type": obj.get("market_type"),
            }
        )
        return _obj
